##############################################
## Robustness Check: Event Window Length
##############################################

rm(list = ls())

##############################################
# Loading Adj Close data:
setwd(wk_dir); source("Code/Helper_Scripts/AdjClose_DataClean.R")

# Loading HR data:
setwd(wk_dir); load("Data/FirmInfo.Rdata")

# Loading Abnormal Return Function:
setwd(wk_dir); source("Code/Helper_Scripts/AbnormalRet.R")

# Loading Plot Options:
setwd(wk_dir); source("Code/Helper_Scripts/Plot_Options.R")

# Summing over different event window durations:
CAR_T <- function(T, df = abnormal_df) {
	if(T == 1) {
		return(df[, T + 1])
	} else {
		last_col <- T + 1
		first_col <- 2
		return(rowSums(df[, first_col:last_col], na.rm = TRUE))
	}
}

##############################################
# Calculating CARs for April 17:
##############################################

# Defining Event:
event <- ymd('2013-04-17')

# Defining Estimation Window
end_est_window <- event - days(60)
begin_est_window <- end_est_window - days(200)
# Acemoglu et al use 250 days.

# Defining Event Window:
begin_event_window <- event
end_event_window <- event + days(25)

# Mkt Index:
sandp_df <- subset(price_df, subset = c(ticker_sym == "^GSPC"))
ftse_df <- subset(price_df, subset = c(ticker_sym == "^FTSE"))

test <- Abnormal_Return('RDSB.L')
sum(test, na.rm = TRUE)

# Unique Firms:
firms <- unique(price_df$ticker_sym[price_df$ticker_sym %nin% c("^GSPC", "^FTSE", "^FTLC", "^FTMC")])

# Calcluating Abnormal Return for the event window:
abnormal_mat <- matrix(NA, ncol = length(test), nrow = length(firms))
abnormal_mat <- suppressWarnings(do.call('rbind', lapply(firms, Abnormal_Return)))
abnormal_df <- data.frame(firms, abnormal_ret = abnormal_mat)

Ts <- 1:18
car_mat <- matrix(NA, nrow = nrow(abnormal_df), ncol = length(Ts - 1))

# Calculating CARs for different window durations
for(t in Ts){
	car_mat[, t] <- CAR_T(t)
}

car_mat <- as.data.frame(car_mat)
names(car_mat) <- paste("car_", Ts, sep = "")
car_df <- data.frame(firms = abnormal_df$firms, car_mat)

##############################################
# Merging:
reg_df <- merge(rep_firm, car_df, by.x = "ticker_ya", by.y = "firms")

##############################################
# Cleaning and adding a few indicators:
reg_df$min_physint <- with(reg_df,
	ifelse(min_physint == Inf | min_physint == -Inf, NA, min_physint))

reg_df$foreign <- with(reg_df,
	ifelse(country_iso == "US", "US", "Foreign"))
reg_df$foreign <- with(reg_df, relevel(factor(foreign), ref = "US"))

##############################################
## Analysis:
##############################################

setwd(wk_dir); load("Data/April17.Rdata")
est_sample <- rep_17apr$ticker_ya

Coef_Fn <- function(T, df = reg_df) {
	require(lmtest)
	var <- paste("car_", T, sep = "")

	# Trimming data:
	p <- .005
	orbis_trim <- subset(df,
		subset = ticker_ya %in% est_sample,
		select = names(df) %in% c(var, "min_physint", "foreign", "ticker_ya"))

	names(orbis_trim)[grepl("car", names(orbis_trim))] <- "car"

	# Calculating beta_hat from model 1:
	m <- lm(car ~ min_physint, data = orbis_trim)
	b1 <- coeftest(m, vcovHC(m))[2, 1:2]
	m1 <- c(as.numeric(b1[1]), b1[1] + c(-1,1) * 1.645 * b1[2])


	# Calculating beta_hat from model 3:
	m <- lm(car ~ min_physint + foreign + min_physint:foreign, data = orbis_trim)
	# b2 <- coeftest(m, vcovHC(m, type = "HC3"))[3, 1:2]
	# m3_b2 <- c(as.numeric(b2[1]), b2[1] + c(-1,1) * 1.645 * b2[2])

	b3 <- coeftest(m, vcovHC(m, type = "HC3"))[4, 1:2]
	m3_b3 <- c(as.numeric(b3[1]), b3[1] + c(-1,1) * 1.645 * b3[2])
	return(c(m1, m3_b3))
}

# Running models 1 and 3 for different window durations:
results_df <- as.data.frame(sapply(Ts, Coef_Fn))
Ncols <- ncol(results_df)

# Cleaning up dataframe of results
names(results_df) <- paste("T_", Ts, sep ="")
library(reshape)
results_df <- melt(results_df)
detach(package:reshape)
results_df$model <- factor(rep(c(1,1,1,3,3,3), Ncols))
results_df$quant <- factor(rep(c("est", "lb", "ub"), Ncols * 2))

model3_df <- as.data.frame(cbind(
	select(filter(results_df, quant == "est", model ==3), variable, model, value),
	select(filter(results_df, quant == "lb", model ==3), value),
	select(filter(results_df, quant == "ub", model ==3), value)))
names(model3_df) <- c("window", "model", "est", "lb", "ub")

# Model 3 Plot:
f2 <- ggplot(data = model3_df[1:10, ],
	aes(x = window, y = est, ymin = lb, ymax = ub)) +
	geom_linerange() +
	geom_point(shape = 15) +
	geom_hline(yintercept = 0, lty = 2, color = "red") +
	ylab(expression(paste(hat(phi), " from Model 3"))) +
	xlab("Event Window Duration") +
	scale_x_discrete(labels = 1:14) +
	coord_cartesian(ylim = c(-0.02, 0.01)) +
	theme_bw() + dc_opts


##############################################
# Calculating CARs for 5 March:
##############################################
# Defining Event:
event <- ymd('2012-03-05')

# Defining Estimation Window
end_est_window <- event - days(60)
begin_est_window <- end_est_window - days(200)
# Acemoglu et al use 250 days.

# Defining Event Window:
begin_event_window <- event
end_event_window <- event + days(25)

# Mkt Index:
sandp_df <- subset(price_df, subset = c(ticker_sym == "^GSPC"))
ftse_df <- subset(price_df, subset = c(ticker_sym == "^FTSE"))

test <- Abnormal_Return('RDSB.L')
sum(test, na.rm = TRUE)

# Unique Firms:
firms <- unique(price_df$ticker_sym[price_df$ticker_sym %nin% c("^GSPC", "^FTSE", "^FTLC", "^FTMC")])

# Calcluating Abnormal Return for the event window:
abnormal_mat <- matrix(NA, ncol = length(test), nrow = length(firms))
abnormal_mat <- suppressWarnings(do.call('rbind', lapply(firms, Abnormal_Return)))
abnormal_df <- data.frame(firms, abnormal_ret = abnormal_mat)

Ts <- 1:18
car_mat <- matrix(NA, nrow = nrow(abnormal_df), ncol = length(Ts - 1))

# Calculating CARs for different window durations
for(t in Ts){
	car_mat[, t] <- CAR_T(t)
}

car_mat <- as.data.frame(car_mat)
names(car_mat) <- paste("car_", Ts, sep = "")
car_df <- data.frame(firms = abnormal_df$firms, car_mat)

##############################################
# Merging:
reg_df <- merge(rep_firm, car_df, by.x = "ticker_ya", by.y = "firms")

##############################################
# Cleaning and adding a few indicators:
reg_df$min_physint <- with(reg_df,
	ifelse(min_physint == Inf | min_physint == -Inf, NA, min_physint))

reg_df$foreign <- with(reg_df,
	ifelse(country_iso == "US", "US", "Foreign"))
reg_df$foreign <- with(reg_df, relevel(factor(foreign), ref = "US"))

##############################################
## Analysis:
##############################################

setwd(wk_dir); load("Data/March5.Rdata")
est_sample <- rep_5mar$ticker_ya

# Running models 1 and 3 for different window durations:
results_df <- as.data.frame(sapply(Ts, Coef_Fn))
Ncols <- ncol(results_df)

# Cleaning up dataframe of results
names(results_df) <- paste("T_", Ts, sep ="")
library(reshape)
results_df <- melt(results_df)
detach(package:reshape)
results_df$model <- factor(rep(c(1,1,1,3,3,3), Ncols))
results_df$quant <- factor(rep(c("est", "lb", "ub"), Ncols * 2))

model3_5mar_df <- as.data.frame(cbind(
	select(filter(results_df, quant == "est", model ==3), variable, model, value),
	select(filter(results_df, quant == "lb", model ==3), value),
	select(filter(results_df, quant == "ub", model ==3), value)))
names(model3_5mar_df) <- c("window", "model", "est", "lb", "ub")

# Model 3 Plot:
f1 <- ggplot(data = model3_5mar_df[1:10, ],
	aes(x = window, y = est, ymin = lb, ymax = ub)) +
	geom_linerange() +
	geom_point(shape = 15) +
	geom_hline(yintercept = 0, lty = 2, color = "red") +
	ylab(expression(paste(hat(phi), " from Model 3"))) +
	xlab("Event Window Duration") +
	scale_x_discrete(labels = 1:14) +
	coord_cartesian(ylim = c(-0.02, 0.01)) +
	theme_bw() + dc_opts

grid.arrange(f1, f2, nrow = 2)
