##############################################
## Figure 6: Distribution of Placebo Tests
##############################################

rm(list = ls())

##############################################
# Loading Adj Close data:
setwd(wk_dir); source("Code/Helper_Scripts/AdjClose_DataClean.R")

# Loading Firm data:
setwd(wk_dir); load("Data/FirmInfo.Rdata")

# Loading Abnormal Return Function:
setwd(wk_dir); source("Code/Helper_Scripts/AbnormalRet.R")

# Loading Plot Options:
setwd(wk_dir); source("Code/Helper_Scripts/Plot_Options.R")

##############################################
# Generating a sequence of dates to draw placebo:
##############################################

# Start date = end of rehearing event window + (260) days
start <- ymd('2012-03-15') + days(260)
end <- ymd('2013-04-06')
possible_placebo <- seq(from = start, to = end, by = "1 day")

# Drawing Dates:
set.seed(1234)
Nsims <- 80
placebo_event <- c('2012-03-05', as.character(sample(possible_placebo, Nsims)), '2013-04-17')
placebo_event <- placebo_event[order(placebo_event)]

##############################################
## Looping over placebo dates:
##############################################

col_names <- c("m1_est", "m1_se", "m1_tstat", "m3_est", "m3_se", "m3_tstat")
placebo_coef <- as.data.frame(matrix(NA, nrow = Nsims + 2, ncol = length(col_names)))
names(placebo_coef) <- col_names

# Unique Firms:
firms <- unique(price_df$ticker_sym[price_df$ticker_sym %nin% c("^GSPC", "^FTSE")])

# Mkt Index: S&P 500:
sandp_df <- filter(price_df, ticker_sym == "^GSPC")
ftse_df <- filter(price_df, ticker_sym == "^FTSE")
# Acemoglu et al use the S&P 500.

pb <- txtProgressBar(min = 0, max = (Nsims + 2), style = 3)
i <- 1
for(i in 1:(Nsims + 2)){
	# Defining Event:
	event <- ymd(placebo_event[i])

	# Defining Estimation Window
	end_est_window <- event - days(60)
	begin_est_window <- end_est_window - days(200)
	# Acemoglu et al use 250 days.

	# Defining Event Window:
	begin_event_window <- event
	end_event_window <- event + days(10)

	test <- Abnormal_Return(firms[1])

	# Calcluating Abnormal Return for the event window:
	abnormal_mat <- matrix(NA, ncol = length(test), nrow = length(firms))
	abnormal_mat <- do.call('rbind', lapply(firms, Abnormal_Return))
	abnormal_df <- data.frame(firms, abnormal_ret = abnormal_mat)

	# Summing to find CAR:
	abnormal_df$car <- abnormal_df %>%
		select(starts_with("abnormal")) %>%
		rowSums()

	# Selecting Columns:
	abnormal_df <- abnormal_df %>% select(firms, car)

	# Merging with HR data from subsidiaries
	orbis_final <- merge(rep_firm, abnormal_df,
		by.x = "ticker_ya", by.y = "firms")

	##############################################
	# Cleaning and adding a few indicators:
	orbis_final$min_physint <- with(orbis_final,
		ifelse(min_physint %in% c(Inf, -Inf), NA, min_physint))

	orbis_final$foreign <- with(orbis_final,
		ifelse(country_iso == "US", "US", "Foreign"))

	##############################################
	## Regression Analysis:
	##############################################
	# Trimming data:
	p <- .005
	orbis_trim <- orbis_final %>%
		filter(car >= quantile(car, p, na.rm = TRUE)) %>%
		filter(car <= quantile(car, 1-p, na.rm = TRUE))
	rm(orbis_final)
	orbis_trim$foreign <- relevel(factor(orbis_trim$foreign), ref = "US")

	##############################################
	# Calculating beta_hat from model 1:
	m <- lm(car ~ min_physint, data = orbis_trim)
	placebo_coef[i, 1:3] <- coeftest(m, vcovHC(m))[2, c(1:3)]

	# Calculating beta_hat from model 3:
	m <- lm(car ~ min_physint + foreign + min_physint:foreign, data = orbis_trim)
	placebo_coef[i, 4:6] <- coeftest(m, vcovHC(m))[4, 1:3]
	rm(orbis_trim)

	setTxtProgressBar(pb, i)
}

placebo_coef$date <- placebo_event
placebo_coef$type <- c("5March", rep("Placebo Date", Nsims), "17April")
placebo_coef$label <- c("Rehearing", rep("", Nsims), "Court Decision")
beep(2)

##############################################
## Plotting Distribution of Coefficients:
##############################################

library(RColorBrewer)
f_betas <- ggplot(data = placebo_coef,
		aes(x = m1_est, y = m3_est, color = type, shape = type)) +
	geom_point() +
	#geom_rug() +
	geom_text(aes(label = label), hjust = -.1, show_guide = FALSE, position = position_jitter(height = .002)) +
	xlab(expression(paste(hat(beta), " from Model 1"))) +
	ylab(expression(paste(hat(phi), " from Model 3"))) +
	scale_colour_manual("", values = brewer.pal(9, "Set1")[c(1:2,9)], guide = FALSE) +
	scale_x_continuous(breaks = c(-.005, 0, .005)) +
	scale_y_continuous(breaks = c(-.015, 0, .015), limits = c(-.015, .015)) +
	scale_shape_discrete("", guide = FALSE) +
	theme_bw() + theme(legend.position = "bottom") + dc_opts

f_tstats <- ggplot(data = placebo_coef,
	aes(x = m1_tstat, y = m3_tstat, color = type, shape = type)) +
	geom_point() +
	#geom_rug() +
	geom_vline(xintercept = -1.645, lty = 3) +
	geom_hline(yintercept = -1.645, lty = 3) +
	geom_text(aes(label = label), hjust = -.1, show_guide = FALSE) +
	xlab(expression(paste("t-stat(", hat(beta), ") from Model 1"))) +
	ylab(expression(paste("t-stat(", hat(phi), ") from Model 3"))) +
	scale_colour_manual("", values = brewer.pal(9, "Set1")[c(1:2,9)], guide = FALSE) +
	scale_y_continuous(breaks = c(-3, -1.645, 0, 1.645, 3), limits = c(-3, 3)) +
	scale_x_continuous(breaks = c(-3, -1.645, 0, 1.645, 3), limits = c(-3, 3)) +
	scale_shape_discrete("", guide = FALSE) +
	theme_bw() + theme(legend.position = "bottom") + dc_opts

grid.arrange(f_betas, f_tstats, nrow = 1)
